#
# spec file for package libepc
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2009 Dominique Leuenberger, Almere, The Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libepc
Version:        0.4.6
Release:        6.6
Summary:        Easy Publish and Consume Library
License:        LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
URL:            https://live.gnome.org/libepc/
Source:         https://download.gnome.org/sources/libepc/0.4/%{name}-%{version}.tar.xz

BuildRequires:  gdbm-devel
BuildRequires:  intltool
BuildRequires:  libgnutls-devel
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(avahi-ui-gtk3)
BuildRequires:  pkgconfig(glib-2.0) >= 2.36
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(uuid)

%description
The Easy Publish and Consume library provides methods to publish
data via HTTPS, announce data via DNS-SD, re-find and consume this
data.

%package 1_0-3
Summary:        Easy Publish and Consume Library
Group:          System/Libraries
# For lang package to be installable:
Provides:       %{name} = %{version}
# Version 0.4.x wrongly packaged libepc-1.0.so.3 in libepc-1_0-2
Conflicts:      libepc-1_0-2 >= 0.4

%description 1_0-3
The Easy Publish and Consume library provides methods to publish
data via HTTPS, announce data via DNS-SD, re-find and consume this
data.

This library can be used as a key/value store published to the
network, using encryption, authentication and service discovery.

%package devel
Summary:        Easy Publish and Consume Library
Group:          Development/Libraries/GNOME
Requires:       %{name}-1_0-3 = %{version}

%description devel
Development headers for libepc.

The Easy Publish and Consume library provides methods to publish
data via HTTPS, announce data via DNS-SD, re-find and consume this
data.

%lang_package

%prep
%autosetup -p1

%build
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name}

%post 1_0-3 -p /sbin/ldconfig
%postun 1_0-3 -p /sbin/ldconfig

%files 1_0-3
%{_libdir}/%{name}*.so.*

%files devel
%{_includedir}/%{name}-1.0
%{_includedir}/%{name}-ui-1.0
%{_libdir}/*.so
%{_libdir}/pkgconfig/libepc*.pc
%{_datadir}/gtk-doc/html/%{name}-1.0
# Own these repositories to not depend on gtk-doc while building:
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html

%files lang -f %{name}.lang

%changelog
* Mon Apr 25 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Rename libepc-1_0-2 subpackage to libepc-1_0-3, matching the
  actual libraries provided.
- Conflict libepc-1_0-3 with libepc-1_0-2 >= 0.4: version 0.4 was
  wrongly packaged, the conflict aids with the migrations path.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Tue Aug 27 2019 Jan Engelhardt <jengelh@inai.de>
- Compact descriptions. Hard trim descriptions in secondary
  subpackages.
* Tue Aug 13 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Drop manual gtk2-devel, libavahi-devel, libavahi-glib-devel and
  libsoup-devel Requires from devel sub-package.
- Run spec-cleaner, modernize spec.
* Fri Jul  7 2017 zaitor@opensuse.org
- Update to version 0.4.6:
  + Examples: Avoid some compiler warnings in the examples.
- Changes from version 0.4.5:
  + Replace (deprecated) g_thread_create() with g_thread_new().
  + Remove use of deprecated g_type_init().
  + Replace (deprecated) GStaticRecMutex with GRecMutex
  + Don't use g_thread_init() or g_thread_supported().
  + Avoid several compiler warnings.
* Tue Jan 31 2012 dimstar@opensuse.org
- Update to version 0.4.4:
  + Correct the libepc-1.0 pkg-config file to mention gnutls,
    bgo#668882.
- Add xz BuildRequires on openSUSE <= 12.1, in order to be able to
  decompress the xz-compressed tarball.
* Tue Nov 22 2011 vuntz@opensuse.org
- Update to version 0.4.3:
  + Correct the libepc-ui-1.0 pkg-config file (bgo#664502).
* Thu Oct 13 2011 vuntz@opensuse.org
- Update to version 0.4.2:
  + Build:
  - examples: Fix linker problems.
  - Avoid use of deprecated G_CONST_RETURN (bgo#660558).
* Fri Sep 30 2011 dimstar@opensuse.org
- Update to version 0.4.1:
  + Really use gtk+ 3 in libepc-ui [bgo#657679]
- Drop libepc-git-fixes.patch: fixed upstream.
- Remove gnome-common BuildRequires and call to gnome-autogen.sh,
  as there is no more patch requiring it.
* Fri Sep 16 2011 vuntz@opensuse.org
- Add libepc-git-fixes.patch: fixes from git to really build
  against GTK+ 3. This is needed for the new totem to build
  correctly with libepc.
- Add gnome-common BuildRequires, and call to gnome-autogen.sh,
  needed for above patch.
* Thu May 26 2011 vuntz@opensuse.org
- Add explicit pkgconfig() BuildRequires instead of relying on
  something else to bring them in: gnutls, uuid.
* Tue May 24 2011 dimstar@opensuse.org
- Update to version 0.4.0:
  + Switch to GTK3:
  - Use avahi-ui-gtk3, instead of avahi-ui [bgo#649404]
  + Fix compilation with GSEAL_ENABLE defined.
- Change -devel style BuildRequires to pkgconfig() ones:
  + Old ones: glib2-devel, libavahi-glib-devel, libsoup-devel.
  + New ones: glib-2.0, libsoup-2.4, avahi-ui-gtk3.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Wed Oct  6 2010 prusnak@opensuse.org
- replace Requires with Recommends for -lang subpackage
* Tue Mar 23 2010 vuntz@opensuse.org
- Update to version 0.3.11:
  + Change a string and add a translator comment. bgo#589339.
  + Fix build failure on kFreeBSD. bgo#592474.
  + Use gtk_widget_get_visible() on GTK+ >= 2.19.7. bgo#612108.
  + Modernise autotools configuration. bgo#613316.
  + Fix some compiler warnings.
  + Updated translations.
* Sat May 23 2009 vuntz@novell.com
- Update to version 0.3.10:
  + epc_shell_create_service_browser(): Fix a warning about no
    return value, possibly avoiding a crash elsewhere.
* Mon May 18 2009 vuntz@novell.com
- Do not use tabs, remove trailing white spaces.
- Split lang package.
* Tue May 12 2009 dominique-obs@leuenberger.net
- Initial package, created during Community Week1
